@@ -47,19 +47,16 @@ gog_tool_select_object_point (GogView *view, double x, double y, GogObject **gob
 static void
 gog_tool_select_object_render (GogView *view)
 {
-	ArtVpath *path;
 	GogViewAllocation rect = view->allocation;
 	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (view->model));
 	double line_width = gog_renderer_line_size (view->renderer, style->line.width);
-	
+
 	rect.x -= line_width / 2.0;
 	rect.y -= line_width / 2.0;
 	rect.w += line_width;
 	rect.h += line_width;
 
-	path = gog_renderer_get_rectangle_vpath (&rect);
-	gog_renderer_draw_sharp_path (view->renderer, path);
-	art_free (path);
+	gog_renderer_draw_selection_rectangle (view->renderer, &rect);
 }
 
 static GogTool gog_tool_select_object = {
@@ -656,9 +653,9 @@ gog_view_queue_resize (GogView *view)
 
 	gog_renderer_request_update (view->renderer);
 
-	do
+	do {
 		view->allocation_valid = FALSE; /* in case there is no parent */
-	while (NULL != (view = view->parent) && view->allocation_valid);
+	} while (NULL != (view = view->parent) && view->allocation_valid);
 }
 
 void
@@ -772,9 +769,11 @@ gog_view_render	(GogView *view, GogViewAllocation const *bbox)
 		return;
 
 	if (klass->clip) {
-		gog_renderer_push_clip (view->renderer, 
-			gog_renderer_get_rectangle_vpath (&view->allocation));
+		gog_renderer_push_clip_rectangle (view->renderer, view->allocation.x, view->allocation.y,
+						  view->allocation.w, view->allocation.h);
+
 		klass->render (view, bbox);
+
 		gog_renderer_pop_clip (view->renderer);
 	}
 	else
@@ -849,7 +848,8 @@ gog_view_size_child_request (GogView *view,
  * @target_model : #GogObject
  *
  * Find the GogView contained in @container that corresponds to @model.
- * Returns NULL on error or if @target_model has no view.
+ *
+ * Returns: NULL on error or if @target_model has no view.
  **/
 GogView *
 gog_view_find_child_view  (GogView const *container, GogObject const *target_model)
@@ -914,7 +914,7 @@ gog_view_render_toolkit (GogView *view)
  * gog_view_get_toolkit :
  * @view : #GogView
  *
- * Returns toolkit associated with given view.
+ * Returns: toolkit associated with given view.
  **/
 GSList const *
 gog_view_get_toolkit (GogView *view)
